@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-93c9f5420bfbd80e8b14a192df0f3642
-key: authe_9oC8YLtAh0u9ABEDFgDHJf
+id: authenticate-1.3.3-0fee63ddb48a70d3e37f4eef5824beb7
+key: authe_59W8mD6WqfTFvW6e7J7I9h
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,26 +23,26 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-9oC8YLtAh0u9ABEDFgDHJf
+hs-libraries: HSauthenticate-1.3.3-59W8mD6WqfTFvW6e7J7I9h
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
-    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-76c320bb56047f4b6951f7d6a8e71998
+    http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    tagstream-conduit-0.5.5.3-b744539fdc663e8763385d836cf273a8
+    tagstream-conduit-0.5.5.3-f4f6c6ac192891a95d7f14b8c2cd924f
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
-    xml-conduit-1.3.4-978b9ab149c55d47c395c4e421ee22a7
+    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
